#!/usr/bin/env python

#
#	Simple RPi Radio 
#	Simple Circuits Inc
#
#	03/29/2015 version 0.6
#

#	
# Import Packages
#
import serial
import platform
from Tkinter import *


#	
# Transmit Commands to Radio Module
#
def SendCommand(mode):
	cmd = "MD" + mode + ";"
	port.write(cmd)

def SetFrequency(frq):
	buffer.set(str(frq))
	cmd = "FA00" + str(frq) + "000;"
	port.write(cmd)

#	
# Event Handlers
#
def scan_event():
	global frequencyIndex,frequency,scan
	if scan == TRUE:
		frequencyIndex = (frequencyIndex + 1) % len(myFrequencies)
		SetFrequency(myFrequencies[frequencyIndex])
		root.after(2000, scan_event)


def mouse_wheel(event):
	global frequency
	if frequency > 136000 and frequency < 999999:
		if event.num == 5 or event.delta == -120:
			frequency -= 5
		if event.num == 4 or event.delta == 120:
			frequency += 5
	elif frequency >= 136000 and frequency < 999999:
		if event.num == 4 or event.delta == 120:
			frequency += 5
	elif frequency <= 9999999:
		if event.num == 5 or event.delta == -120:
			frequency -= 5

	SetFrequency(frequency)

	
def text_enter(event):
	global frequency
	if buffer.get():
		count_str = buffer.get()
		value = int(count_str)
		if value > 136000 and value < 999999:
			frequency = value
			SetFrequency(frequency)


def button_clicked(mode):
	global frequencyIndex,frequency,scan
	B1.configure(fg='black')
	B2.configure(fg='black')
	B3.configure(fg='black')
	B4.configure(fg='black')

	if (mode == "0"):
		B1.configure(fg='orange red')
		frequencyIndex = (frequencyIndex + 1) % len(myFrequencies)
		SetFrequency(myFrequencies[frequencyIndex])
	elif (mode == "1"):
		if scan == TRUE:
			msg = "Scan OFF"
			scan = FALSE
#			root.after_cancel()
		else:
			msg = "Scanning"
			scan = TRUE
			root.after(2000, scan_event)
		B2.configure(fg='orange red', text=msg)
	elif (mode == "2"):
		B3.configure(fg='orange red')
		cmd = "VU" + ";"
		port.write(cmd)
	elif (mode == "3"):
		B4.configure(fg='orange red')
		cmd = "VD" + ";"
		port.write(cmd)


#
# User Interface
#
myFrequencies=[144390,146880,449240,146595,146575,146445,449080,145180,146730,147030,147075,147130]
frequencyIndex = 0
scan = FALSE;
frequency = 144390
root = Tk()
root.title('Simple RPi Radio v0.6')
root['bg'] = 'white'

if platform.system() == 'Windows':
# 	Windows OS
	root.bind("<MouseWheel>", mouse_wheel)
	port = serial.Serial("COM4", 19200, 8, 'N', 1, timeout=3)
else:
# 	Linux OS
	root.bind("<Button-4>", mouse_wheel)
	root.bind("<Button-5>", mouse_wheel)
	port = serial.Serial("/dev/ttyAMA0", 19200, 8, 'N', 1, timeout=3)

buffer = StringVar()
buffer.set(frequency)
label = Entry(root, textvariable = buffer, font=('courier', 80, 'bold'), width=10, fg='orange red', bg='white', justify=CENTER, bd="0")
label.pack(padx=70, pady=40)
label.bind('<Return>', text_enter)

B1 = Button(root, text="Memory", command = lambda: button_clicked("0"))
B1.pack(side = LEFT, padx=70, pady=20)
B1.configure(fg='orange red')

B2 = Button(root, text="Scan OFF", command = lambda: button_clicked("1"))
B2.pack(side = LEFT, padx=70, pady=20)

B3 = Button(root, text="Volume Up", command = lambda: button_clicked("2"))
B3.pack(side = LEFT, padx=70, pady=20)

B4 = Button(root, text="Volume Dn", command = lambda: button_clicked("3"))
B4.pack(side = LEFT, padx=70, pady=20)

SetFrequency(frequency)

root.mainloop()
