//----------------------------------------------------------------------------
//
//  Simple Circuits Inc. VHF/UHF Transceiver Firmware
//
//	Copyright 2015 Simple Circuits Inc.
//
//	10/09/2016	Version 1
//	Added FCS (CRC) checking on received packets
//
//	04/06/2015	Version 0
//
//
//----------------------------------------------------------------------------
#include "stm32f4xx_hal.h"


//----------------------------------------------------------------------------
//
//	Definitions
//
//----------------------------------------------------------------------------
#define	FW_VERSION		1				// firmware version

#define	DEFAULT_START_FRQ	144390000

#define	TRUE			1
#define	FALSE			0

#define	MODE_FM			0				// operating modes
#define	MODE_1200		1
#define	MODE_9600		2
#define	MODE_DSTAR		3
#define	MODE_C4FM		4

#define RADIO_NSS0()		(HAL_GPIO_WritePin(GPIOB, GPIO_PIN_11, GPIO_PIN_RESET))	// PB11
#define RADIO_NSS1()		(HAL_GPIO_WritePin(GPIOB, GPIO_PIN_11, GPIO_PIN_SET))	// PB11
#define RADIO_RST0()		(HAL_GPIO_WritePin(GPIOC, GPIO_PIN_8, GPIO_PIN_RESET))	// PC8
#define RADIO_RST1()		(HAL_GPIO_WritePin(GPIOC, GPIO_PIN_8, GPIO_PIN_SET))	// PC8
#define IsCarrierDetected()	HAL_GPIO_ReadPin(GPIOB, GPIO_PIN_12)					// PB12, GPIO0
#define SW1()				HAL_GPIO_ReadPin(GPIOB, GPIO_PIN_0)						// PB0

#define LED_ON()			(HAL_GPIO_WritePin(GPIOC, GPIO_PIN_0, GPIO_PIN_RESET))	// PC0
#define LED_OFF()			(HAL_GPIO_WritePin(GPIOC, GPIO_PIN_0, GPIO_PIN_SET))	// PC0

#define	AUDIO_ON()			(HAL_GPIO_WritePin(GPIOC, GPIO_PIN_1, GPIO_PIN_SET))	// PC1
#define	AUDIO_OFF()			(HAL_GPIO_WritePin(GPIOC, GPIO_PIN_1, GPIO_PIN_RESET))	// PC1

#define TP5_LO()			(HAL_GPIO_WritePin(GPIOA, GPIO_PIN_2, GPIO_PIN_RESET))	// PA2
#define TP5_HI()			(HAL_GPIO_WritePin(GPIOA, GPIO_PIN_2, GPIO_PIN_SET))	// PA2


//----------------------------------------------------------------------------
//
//	Global Variables
//
//----------------------------------------------------------------------------
extern volatile uint16_t DelayTimer;		// delay timer variable for timing functions
extern volatile uint16_t SquelchTimer;		// adds delays before turning off audio
extern uint16_t OperatingMode;				// radio operating mode
extern uint16_t Volume;						// volume variable
extern int32_t	RxBuffer[64];				// receive samples for demodulators
extern uint16_t	RxInputPtr;					// input pointer into rx buffer
extern uint16_t	RxOutputPtr;				// output pointer into rx buffer
extern volatile uint8_t  UartRxFifo[256];			// UART receive fifo
extern volatile uint16_t UartRxInPtr, UartRxOutPtr;	// UART receive fifo input/output pointers
extern int32_t	FirStage[64];				// FIR register buffer for audio
extern uint16_t FirStagePtr;

extern const int32_t FIR_BPF_COEFF[64];		// BPF coefficients table


//----------------------------------------------------------------------------
//
//	Function prototypes
//
//----------------------------------------------------------------------------
void Delay1Ms(uint16_t);					// main.c

void RadioISR(void);						// radio.c
void SetFrequency(uint64_t);
void ConfigureRadio(void);

void RunTnc1200(void);						// TNC1200.c

void UART_RxProcessor(void);				// usart.c
void UART_TxProcessor(void);
void UART_SendData(uint8_t *, uint16_t);
void UART_SendString(char *);
void UART_SendByte(uint16_t);

int32_t Mixer(uint16_t, int32_t);			// dsp.c
uint32_t SquareAndSum(int32_t, int32_t);
int32_t Fir(int32_t *, uint16_t, const int32_t *, uint16_t);



/* [] END OF FILE */
