//------------------------------------------------------------------------------
//
//  Simple Circuits Inc. Simple RPi VHF/UHF Transceiver Firmware
//
//	Receiver register configurations
//
//	Copyright 2015 Simple Circuits Inc.
//
//	12/24/2014
//
//------------------------------------------------------------------------------
#include "stm32f4xx_hal.h"


//----------------------------------------------------------------------------
//
//	RF settings for CC1120
//
//----------------------------------------------------------------------------
uint8_t const RF_SETTINGS[] = {
      29,  // IOCFG3       			GDO3Output Pin Configuration, CFM RX sample clock
	  16,  // IOCFG2              	GDO2Output Pin Configuration, Carrier sense valid output
	0x30,  // IOCFG1              	GDO1Output Pin Configuration, not used, tristate
	  17,  // IOCFG0              	GDO0Output Pin Configuration, Carrier sense output
    0x93,  // SYNC3                 Sync Word Configuration [31:24]
    0x0B,  // SYNC2                 Sync Word Configuration [23:16]
    0x51,  // SYNC1                 Sync Word Configuration [15:8]
    0xDE,  // SYNC0                 Sync Word Configuration [7:0]
    0x0A,  // SYNC_CFG1             Sync Word Detection Configuration Reg. 1
    0x03,  // SYNC_CFG0             Sync Word Length Configuration Reg. 0, no sync
    0x48,  // DEVIATION_M           Frequency Deviation Configuration, 5 KHz deviation
    0x03,  // MODCFG_DEV_E          Modulation Format and Frequency Deviation Configur..
    0x1C,  // DCFILT_CFG            Digital DC Removal Configuration
    0x00,  // PREAMBLE_CFG1         Preamble Length Configuration Reg. 1, no preamble
    0x0A,  // PREAMBLE_CFG0         Preamble Detection Configuration Reg. 0, preamble detection disabled
    0x40,  // FREQ_IF_CFG           RX Mixer Frequency Configuration
    0xC6,  // IQIC                  Digital Image Channel Compensation Configuration
    0x4D,  // CHAN_BW               Channel Filter Configuration, 9.6KHz RX BW, RX sample clock is 4x RX filter BW (38.4KHz)
    0x06,  // MDMCFG1               General Modem Parameter Configuration Reg. 1, fifo disabled
    0x4D,  // MDMCFG0               General Modem Parameter Configuration Reg. 0, transparent mode enabled, 1x decimination, filters enabled
    0x40,  // SYMBOL_RATE2          Symbol Rate Configuration Exponent and Mantissa [1..
    0x62,  // SYMBOL_RATE1          Symbol Rate Configuration Mantissa [15:8]
    0x4E,  // SYMBOL_RATE0          Symbol Rate Configuration Mantissa [7:0]
    0x20,  // AGC_REF               AGC Reference Level Configuration
    0x0,  // AGC_CS_THR            Carrier Sense Threshold Configuration, 0 = -102 dbm, 10 = -92 dbm
    0x00,  // AGC_GAIN_ADJUST       RSSI Offset Configuration
    0x91,  // AGC_CFG3              Automatic Gain Control Configuration Reg. 3
    0x20,  // AGC_CFG2              Automatic Gain Control Configuration Reg. 2
    0x0A,  // AGC_CFG1              Automatic Gain Control Configuration Reg. 1
    0xCF,  // AGC_CFG0              Automatic Gain Control Configuration Reg. 0
   	0x00,  // FIFO_CFG      		FIFO Configuration
    0x00,  // DEV_ADDR              Device Address Configuration
    0x0B,  // SETTLING_CFG          Frequency Synthesizer Calibration and Settling Con..
 	0x0B,  // FS_CFG                Frequency Synthesizer Configuration
    0x08,  // WOR_CFG1              eWOR Configuration Reg. 1
    0x21,  // WOR_CFG0              eWOR Configuration Reg. 0
    0x00,  // WOR_EVENT0_MSB        Event 0 Configuration MSB
    0x00,  // WOR_EVENT0_LSB        Event 0 Configuration LSB
    0x07,  // PKT_CFG2              Packet Configuration Reg. 2, transparent serial mode
    0x00,  // PKT_CFG1              Packet Configuration Reg. 1
    0x40,  // PKT_CFG0              Packet Configuration Reg. 0, infinite packet length mode
    0x3F,  // RFEND_CFG1            RFEND Configuration Reg. 1, stay in RX mode after receiving packet
    0x00,  // RFEND_CFG0            RFEND Configuration Reg. 0
    0x7F,  // PA_CFG2               Power Amplifier Configuration Reg. 2
    0x56,  // PA_CFG1               Power Amplifier Configuration Reg. 1
    0x7E,  // PA_CFG0               Power Amplifier Configuration Reg. 0
    0xFF   // PKT_LEN               Packet Length Configuration
};


uint8_t const EXTENDED_RF_SETTINGS[56] = {
    0x00,	// IF_MIX_CFG            IF Mix Configuration
    0x22,	// FREQOFF_CFG           Frequency Offset Correction Configuration
    0x0B,	// TOC_CFG               Timing Offset Correction Configuration
    0x00,	// MARC_SPARE            MARC Spare
    0x00,	// ECG_CFG               External Clock Frequency Configuration
    0x0,	//1,	// CFM_DATA_CFG          Custom frequency modulation enable, Enable CFM mode
    0x01,	// EXT_CTRL              External Control Configuration
    0x00,	// RCCAL_FINE            RC Oscillator Calibration Fine
    0x00,	// RCCAL_COARSE          RC Oscillator Calibration Coarse
    0x00,	// RCCAL_OFFSET          RC Oscillator Calibration Clock Offset
    0x00,	// FREQOFF1              Frequency Offset MSB
    0x00,	// FREQOFF0              Frequency Offset LSB
	0x6C,	// FREQ2                 Frequency Configuration [23:16], 144.39 MHz
	0x4A,	// FREQ1                 Frequency Configuration [15:8]
	0xE1,	// FREQ0                 Frequency Configuration [7:0]
    0x02,	// IF_ADC2               Analog to Digital Converter Configuration Reg. 2
    0xA6,	// IF_ADC1               Analog to Digital Converter Configuration Reg. 1
    0x04,	// IF_ADC0               Analog to Digital Converter Configuration Reg. 0
    0x00,	// FS_DIG1               Frequency Synthesizer Digital Reg. 1
    0x5F,	// FS_DIG0               Frequency Synthesizer Digital Reg. 0 
    0x00,	// FS_CAL3               Frequency Synthesizer Calibration Reg. 3
    0x20,	// FS_CAL2               Frequency Synthesizer Calibration Reg. 2
    0x40,	// FS_CAL1               Frequency Synthesizer Calibration Reg. 1
    0x0E,	// FS_CAL0               Frequency Synthesizer Calibration Reg. 0
    0x28,	// FS_CHP                Frequency Synthesizer Charge Pump Configuration
    0x03,	// FS_DIVTWO             Frequency Synthesizer Divide by 2
    0x00,	// FS_DSM1               FS Digital Synthesizer Module Configuration Reg. 1
    0x33,	// FS_DSM0               FS Digital Synthesizer Module Configuration Reg. 0
    0xFF,	// FS_DVC1               Frequency Synthesizer Divider Chain Configuration ..
    0x17,	// FS_DVC0               Frequency Synthesizer Divider Chain Configuration .. 
    0x00,	// FS_LBI                Frequency Synthesizer Local Bias Configuration
    0x50,	// FS_PFD                Frequency Synthesizer Phase Frequency Detector Con..
    0x6E,	// FS_PRE                Frequency Synthesizer Prescaler Configuration
    0x14,	// FS_REG_DIV_CML        Frequency Synthesizer Divider Regulator Configurat..
    0xAC,	// FS_SPARE              Frequency Synthesizer Spare
    0x14,	// FS_VCO4               FS Voltage Controlled Oscillator Configuration Reg..
    0x00,	// FS_VCO3               FS Voltage Controlled Oscillator Configuration Reg..
    0x00,	// FS_VCO2               FS Voltage Controlled Oscillator Configuration Reg..
    0x00,	// FS_VCO1               FS Voltage Controlled Oscillator Configuration Reg..
    0xB4,	// FS_VCO0               FS Voltage Controlled Oscillator Configuration Reg..
    0x00,	// GBIAS6                Global Bias Configuration Reg. 6
    0x02,	// GBIAS5                Global Bias Configuration Reg. 5
    0x00,	// GBIAS4                Global Bias Configuration Reg. 4
    0x00,	// GBIAS3                Global Bias Configuration Reg. 3
    0x10,	// GBIAS2                Global Bias Configuration Reg. 2
    0x00,	// GBIAS1                Global Bias Configuration Reg. 1
    0x00,	// GBIAS0                Global Bias Configuration Reg. 0
    0x01,	// IFAMP                 Intermediate Frequency Amplifier Configuration
    0x01,	// LNA                   Low Noise Amplifier Configuration
    0x01,	// RXMIX                 RX Mixer Configuration
    0x0E,	// XOSC5                 Crystal Oscillator Configuration Reg. 5
    0xA0,	// XOSC4                 Crystal Oscillator Configuration Reg. 4
    0x03,	// XOSC3                 Crystal Oscillator Configuration Reg. 3
    0x04,	// XOSC2                 Crystal Oscillator Configuration Reg. 2, Rx cont 0x04
    0x03,	// XOSC1                 Crystal Oscillator Configuration Reg. 1
    0x00,	// XOSC0                 Crystal Oscillator Configuration Reg. 0
};

/* [] END OF FILE */
