/**
  ******************************************************************************
  * @file    stm32f4xx_it.c
  * @date    23/12/2014 16:05:55
  * @brief   Interrupt Service Routines.
  ******************************************************************************
  *
  * COPYRIGHT(c) 2014 STMicroelectronics
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "stm32f4xx_hal.h"
#include "stm32f4xx.h"
#include "stm32f4xx_it.h"
/* USER CODE BEGIN 0 */

#include "radio.h"

extern uint16_t DelayTimer;

uint16_t Decimator = 4;
int32_t Intg1,Intg2,Intg3,Intg4;			// integrators
int32_t Comb1,Comb2,Comb3,Comb4;			// comb filter summed outputs
int32_t Comb1Delay,Comb2Delay,Comb3Delay,Comb4Delay;	// comb filter delays


/* USER CODE END 0 */
/* External variables --------------------------------------------------------*/

extern PCD_HandleTypeDef hpcd_USB_OTG_FS;

/******************************************************************************/
/*            Cortex-M4 Processor Interruption and Exception Handlers         */ 
/******************************************************************************/

/**
* @brief This function handles USB On The Go FS global interrupt.
*/
void OTG_FS_IRQHandler(void)
{
  /* USER CODE BEGIN OTG_FS_IRQn 0 */

  /* USER CODE END OTG_FS_IRQn 0 */
  HAL_PCD_IRQHandler(&hpcd_USB_OTG_FS);
  /* USER CODE BEGIN OTG_FS_IRQn 1 */

  /* USER CODE END OTG_FS_IRQn 1 */
}

/**
* @brief This function handles System tick timer.
*/
void SysTick_Handler(void)
{
  /* USER CODE BEGIN SysTick_IRQn 0 */

  /* USER CODE END SysTick_IRQn 0 */
  HAL_IncTick();
  HAL_SYSTICK_IRQHandler();
  /* USER CODE BEGIN SysTick_IRQn 1 */

	if (DelayTimer)
		DelayTimer--;

  /* USER CODE END SysTick_IRQn 1 */
}

/**
* @brief This function handles USB On-The-Go FS Wakeup through EXTI Line18 interrupt.
*/
void OTG_FS_WKUP_IRQHandler(void)
{
  /* USER CODE BEGIN OTG_FS_WKUP_IRQn 0 */

  /* USER CODE END OTG_FS_WKUP_IRQn 0 */
  HAL_PCD_IRQHandler(&hpcd_USB_OTG_FS);
  /* USER CODE BEGIN OTG_FS_WKUP_IRQn 1 */

  /* USER CODE END OTG_FS_WKUP_IRQn 1 */
}

/**
* @brief This function handles EXTI Line[9:5] interrupts.
*/
void EXTI9_5_IRQHandler(void)
{
  /* USER CODE BEGIN EXTI9_5_IRQn 0 */

//----------------------------------------------------------------------------
//
//	Receive data ready interrupt routine
//	38.4 KHz, 26 usec
//	Executes in 0.5 usec, 168 MHz CPU
//
//----------------------------------------------------------------------------
	int32_t raw, raw1;

	LED_ON();
	
	// 4th order CIC, decimate by 4, differential delay = 1
	// bit growth is N*log2(4*1) = 4*log2(4) = 8 bits
	Intg1 += (int8_t) SPI2->DR;		// read sample from last SPI transfer
	SPI2->DR = 0;					// get next sample going
	Intg2 += Intg1;
	Intg3 += Intg2;
	Intg4 += Intg3;

	if (--Decimator == 0)		// comb filter section
	{
		Decimator = 4;
		
		Comb1 = Intg4 - Comb1Delay;
		Comb2 = Comb1 - Comb2Delay;
		Comb3 = Comb2 - Comb3Delay;
		Comb4 = Comb3 - Comb4Delay;
		Comb1Delay = Intg4;
		Comb2Delay = Comb1;
		Comb3Delay = Comb2;
		Comb4Delay = Comb3;
		
//		raw = RxBuffer[RxInputPtr++] = Filter_HOLDA24_REG;
//		raw1 = Filter_HOLDB24_REG;
//		Filter_STAGEB24_REG = raw;
//		RxInputPtr &= sizeof(RxBuffer)/4 - 1;

//		if (CARRIER_DETECT_Read())
			DAC->DHR12R1 = 0x0800 ^ (Comb4 >> 4);

	}

	LED_OFF();

	
  /* USER CODE END EXTI9_5_IRQn 0 */
  HAL_GPIO_EXTI_IRQHandler(GPIO_PIN_9);
  /* USER CODE BEGIN EXTI9_5_IRQn 1 */

  /* USER CODE END EXTI9_5_IRQn 1 */
}

/* USER CODE BEGIN 1 */

/* USER CODE END 1 */
/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
