//----------------------------------------------------------------------------
//
//  Simple Circuits Inc. VHF/UHF Transceiver Firmware
//
//	Copyright 2015 Simple Circuits Inc.
//
//	USART routines
//
//	04/06/2015
//
//----------------------------------------------------------------------------
#include "main.h"
#include "stdlib.h"
#include "string.h"
#include <stdio.h>

//----------------------------------------------------------------------------
//
//	Defines
//
//----------------------------------------------------------------------------
//----------------------------------------------------------------------------
//
//	Elecraft K2 serial commands
//
//----------------------------------------------------------------------------
#define	CMD_AI		0x4149				// K2 PowerSDR remote commands
#define	CMD_AN		0x414E
#define	CMD_BG		0x4247
#define	CMD_DS		0x4453
#define	CMD_FA		0x4641
#define	CMD_FB		0x4642
#define	CMD_FR		0x4652
#define	CMD_FT		0x4654
#define	CMD_FW		0x4657
#define	CMD_GT		0x4754
#define	CMD_ID		0x4944
#define	CMD_IF		0x4946
#define	CMD_K2		0x4B32
#define	CMD_KS		0x4B53
#define	CMD_LK		0x4C4B
#define	CMD_MD		0x4D44
#define	CMD_NB		0x4E42
#define	CMD_PA		0x5041
#define	CMD_PC		0x5043
#define	CMD_PS		0x5053
#define	CMD_RA		0x5241
#define	CMD_SQ		0x5351

#define	CMD_VU		0x5655				// volume up command added
#define	CMD_VD		0x5644
#define	CMD_VR		0x5652				// firmware version number


//----------------------------------------------------------------------------
//
//	Global variables
//
//----------------------------------------------------------------------------
uint8_t  UartTxFifo[1024];						// UART transmit fifo
uint16_t UartTxInPtr, UartTxOutPtr;				// UART transmit fifo input/output pointers
volatile uint8_t  UartRxFifo[256];				// UART receive fifo
volatile uint16_t UartRxInPtr, UartRxOutPtr;	// UART receive fifo input/output pointers
uint8_t	 RxCommand[64];
uint16_t RxCommandPtr;


//----------------------------------------------------------------------------
//
//	Function Prototypes
//
//----------------------------------------------------------------------------



//----------------------------------------------------------------------------
//
//	Reads and processes data from USART
//
//----------------------------------------------------------------------------
void UART_RxProcessor(void)
{
	uint8_t rx;
	uint16_t i;
	uint32_t frq;
	char str[64];
	
	if (UartRxInPtr != UartRxOutPtr)
	{
		rx = UartRxFifo[UartRxOutPtr++];
		UartRxOutPtr &= sizeof(UartRxFifo) - 1;
		
		RxCommand[RxCommandPtr++] = rx;				// save in command buffer
		RxCommandPtr &= sizeof(RxCommand) - 1;
		
		if ((rx < ' ') || (RxCommandPtr > 14))		// limit string length
			RxCommandPtr = 0;
		else if (rx == ';')							// command string terminator
		{
			switch (((uint16_t) RxCommand[0] << 8) | RxCommand[1])
			{
				case CMD_FA:						// set/get frequency
					if (RxCommandPtr == 14)
					{
						sscanf( (char *) &RxCommand[4], "%09d", &frq);
						SetFrequency(frq);			// set new frequency
					}
					break;

				case CMD_MD:						// operating mode
					if (RxCommandPtr == 4)
						OperatingMode = RxCommand[2] - '1';	// map Mode to 0 - 9
					break;

				case CMD_VU:						// volume up
					if (RxCommandPtr == 3)
						if (Volume < 7)
							Volume++;
					break;	

				case CMD_VD:						// volume down
					if (RxCommandPtr == 3)
						if (Volume)
							Volume--;
					break;	

				case CMD_VR:						// return version number
					if (RxCommandPtr == 3)
					{
						i = FW_VERSION;
						sprintf(str, "VR%02x\r\n", i);
						UART_SendString(str);
					}
					break;	
				default:
					break;
			}
			RxCommandPtr = 0;
		}
	}
}


//----------------------------------------------------------------------------
//
//	Loads USART with data stored in UsartTxFifo
//
//----------------------------------------------------------------------------
void UART_TxProcessor(void)
{
	if ((UartTxInPtr != UartTxOutPtr) && ((USART1->SR & USART_SR_TXE) != RESET))
	{
		USART1->DR = UartTxFifo[UartTxOutPtr++];
		UartTxOutPtr &= sizeof(UartTxFifo) - 1;
	}
}


//----------------------------------------------------------------------------
//
//	Send a block of bytes to the desired USART port
//
//----------------------------------------------------------------------------
void UART_SendData(uint8_t *ptr, uint16_t len)
{
	for ( ; len; len--)
		UART_SendByte(*ptr++);
}


//----------------------------------------------------------------------------
//
//	Send a character string, NUL terminated, to the desired USART port
//
//----------------------------------------------------------------------------
void UART_SendString(char *ptr)
{
	while (*ptr)
		UART_SendByte(*ptr++);
}


//----------------------------------------------------------------------------
//
//	Send a single byte to the USART port
//
//----------------------------------------------------------------------------
void UART_SendByte(uint16_t chr)
{
	UartTxFifo[UartTxInPtr++] = chr;
	UartTxInPtr &= sizeof(UartTxFifo) - 1;
}

/* [] END OF FILE */
